@@ -12,11 +12,13 @@ class ProperlyEvents(str, Enum):
     STAGE_CHANGED_OFFER = 'stageChangedOffer'
     USER_ENTERED_ALL_OFFER_INFO = 'userEnteredAllOfferInfo'
     SHOWING_UPDATED_OR_CREATED = 'userShowingUpdatedOrCreated'
+    DEAL_CHANGED = 'dealChanged'
     ACCEPTED_OFFER = 'userAcceptedOffer'
     SEARCH_RESULTS_CHANGED = 'searchResultsChanged'
     PPR_FEEDBACK = 'pprFeedback'
     FAVOURITE_ADDED = 'favouriteAdded'
     FAVOURITE_REMOVED = 'favouriteRemoved'
+    FAVOURITES_CHANGED = 'favouritesChanged'
 
 
 STREAM_BY_STAGE = {
